--- formats/format_pcm.c	2012-10-01 00:00:00.000000000 +0000
+++ formats/format_pcm.c	2012-10-01 00:00:00.000000000 +0000
@@ -279,7 +279,11 @@
 #endif
 #endif
 
-static int check_header(FILE *f)
+struct au_desc {
+	uint32_t hdr_size;
+};
+
+static int check_header(struct ast_filestream *fs)
 {
 	AU_HEADER(header);
 	uint32_t magic;
@@ -288,6 +292,8 @@
 	uint32_t encoding;
 	uint32_t sample_rate;
 	uint32_t channels;
+	FILE *f = fs->f;
+	struct au_desc *ad = (struct au_desc *)fs->_private;
 
 	if (fread(header, 1, AU_HEADER_SIZE, f) != AU_HEADER_SIZE) {
 		ast_log(LOG_WARNING, "Read failed (header)\n");
@@ -301,6 +307,7 @@
 	if (hdr_size < AU_HEADER_SIZE) {
 		hdr_size = AU_HEADER_SIZE;
 	}
+	ad->hdr_size = hdr_size;
 /*	data_size = ltohl(header[AU_HDR_DATA_SIZE_OFF]); */
 	encoding = ltohl(header[AU_HDR_ENCODING_OFF]);
 	if (encoding != AU_ENC_8BIT_ULAW) {
@@ -327,17 +334,18 @@
 	return data_size;
 }
 
-static int update_header(FILE *f)
+static int update_header(struct ast_filestream *fs)
 {
 	off_t cur, end;
 	uint32_t datalen;
 	int bytes;
+	FILE *f = fs->f;
+	struct au_desc *ad = (struct au_desc *)fs->_private;
 
 	cur = ftell(f);
 	fseek(f, 0, SEEK_END);
 	end = ftell(f);
-	/* data starts 24 bytes in */
-	bytes = end - AU_HEADER_SIZE;
+	bytes = end - ad->hdr_size;
 	datalen = htoll(bytes);
 
 	if (cur < 0) {
@@ -359,9 +367,13 @@
 	return 0;
 }
 
-static int write_header(FILE *f)
+static int write_header(struct ast_filestream *fs)
 {
 	AU_HEADER(header);
+	struct au_desc *ad = (struct au_desc *)fs->_private;
+	FILE *f = fs->f;
+
+	ad->hdr_size = AU_HEADER_SIZE;
 
 	header[AU_HDR_MAGIC_OFF] = htoll((uint32_t) AU_MAGIC);
 	header[AU_HDR_HDR_SIZE_OFF] = htoll(AU_HEADER_SIZE);
@@ -381,14 +393,14 @@
 
 static int au_open(struct ast_filestream *s)
 {
-	if (check_header(s->f) < 0)
+	if (check_header(s) < 0)
 		return -1;
 	return 0;
 }
 
 static int au_rewrite(struct ast_filestream *s, const char *comment)
 {
-	if (write_header(s->f))
+	if (write_header(s))
 		return -1;
 	return 0;
 }
@@ -396,7 +408,8 @@
 /* XXX check this, probably incorrect */
 static int au_seek(struct ast_filestream *fs, off_t sample_offset, int whence)
 {
-	off_t min = AU_HEADER_SIZE, max, cur;
+	struct au_desc *ad = (struct au_desc *)fs->_private;
+	off_t min = ad->hdr_size, max, cur;
 	long offset = 0, bytes;
 
 	if (fs->fmt->format == AST_FORMAT_G722)
@@ -453,7 +466,7 @@
 	if (ftruncate(fd, cur)) {
 		return -1;
 	}
-	return update_header(fs->f);
+	return update_header(fs);
 }
 
 static off_t au_tell(struct ast_filestream *fs)
@@ -515,6 +528,7 @@
 	.tell = au_tell,
 	.read = pcm_read,
 	.buf_size = BUF_SIZE + AST_FRIENDLY_OFFSET,	/* this many shorts */
+	.desc_size = sizeof(struct au_desc),
 };
 
 static int load_module(void)
